function extractStates = challenge(recordName)

% Scripts that extracts the PCG and states for later Python processing
save([recordName '.mat']);


%% Load the trained parameter matrices for Springer's HSMM model.
% The parameters were trained using 409 heart sounds from MIT heart
% sound database, i.e., recordings a0001-a0409.
load('Springer_B_matrix.mat');
load('Springer_pi_vector.mat');
load('Springer_total_obs_distribution.mat');

%% Load data and resample data
% disp(recordName);
springer_options   = default_Springer_HSMM_options;
[PCG, Fs1] = audioread(['../' recordName '.wav']);  % load data
PCG_resampled      = resample(PCG,springer_options.audio_Fs,Fs1); % resample to springer_options.audio_Fs (1000 Hz)

%% Running runSpringerSegmentationAlgorithm.m to obtain the assigned_states
[assigned_states] = runSpringerSegmentationAlgorithm(PCG_resampled, springer_options.audio_Fs, Springer_B_matrix, Springer_pi_vector, Springer_total_obs_distribution, false); % obtain the locations for S1, systole, s2 and diastole
save([recordName '.mat'], 'PCG_resampled' , '-append');
save([recordName '.mat'], 'assigned_states' , '-append');